==> moodle_1.3.1.orig.tar.gz: moodle/lang/pt_br/resource.php <==
<?PHP // $Id: resource.php,v 1.8 2004/02/09 18:46:39 moodler Exp $ 
      // resource.php - created with Moodle 1.1 development (2003072800)


$string['addresource'] = 'Adicionar material';
$string['chooseafile'] = 'Escolher ou carregar arquivo';
$string['configdefaulturl'] = 'Este valor  usado para completar o form da URL automaticamente quando o material  baseado em URL';
$string['configfilterexternalpages'] = 'Se esta opo estiver ativa, todos os materiais externos como paginas web e arquivos html carregados no servidor sero processados pelos filtros do site, como os autolinks do glossrio. Isto pode reduzir a velocidade de visualizao das pginas do curso - use esta opo apenas nos casos em que for realmente necessrio.';
$string['configframesize'] = 'Quando uma pgina web ou um arquivo  visualizado em um frame, este valor  o tamanho, em pixels, do frame que contm a navegao (top frame).';
$string['configpopup'] = 'A opo de visualizar os materiais em janela popup deve ser preconfigurada?';
$string['configpopupdirectories'] = 'As janelas popup devem mostrar o diretrio de links?';
$string['configpopupheight'] = 'Qual  a altura predefinida das janelas popup?';
$string['configpopuplocation'] = 'As janelas popup devem mostrar a barra de endereo?';
$string['configpopupmenubar'] = 'As janelas popup devem mostrar a barra do menu?';
$string['configpopupresizable'] = 'As janelas popup podem ser redimensionadas?';
$string['configpopupscrollbars'] = 'As janelas popup devem ter a barra de rolagem?';
$string['configpopupstatus'] = 'As janelas popup devem mostrar a brra de estado?';
$string['configpopuptoolbar'] = 'As janelas popup devem  mostrar a barra de instrumentos?';
$string['configpopupwidth'] = 'Qual  a largura predefinida das janelas popup?';
$string['configwebsearch'] = 'Quando se adiciona uma URL como pagina web ou link, este endereo  apresentado como referimento para ajudar o usurio a buscar a URL que est procurando.';
$string['directlink'] = 'Direcionar link a este arquivo';
$string['editingaresource'] = 'Editar material';
$string['example'] = 'Exemplo';
$string['examplereference'] = 'Tobin, K. & Tippins, D (1993) Constructivism as a Referent for Teaching and Learning. In: K. Tobin (Ed) The Practice of Constructivism in Science Education, pp 3-21, Lawrence-Erlbaum, Hillsdale, NJ.';
$string['exampleurl'] = 'http://www.exemplo.com/diretorio/arquivo.html';
$string['fetchclienterror'] = 'Um erro relacionado ao seu navegador impediu o acesso a este endereo (provavelmente o endereo no existe ou foi escrito em modo impreciso)';
$string['fetcherror'] = 'No foi possvel o acesso a esta pgina.';
$string['fetchservererror'] = 'Um erro de acesso ao servidor remoto foi identificado (provavelmente um erro daquele programa) </p>';
$string['filename'] = 'Nome do arquivo';
$string['fulltext'] = 'Texto completo';
$string['htmlfragment'] = 'Fragmento de HTML';
$string['modulename'] = 'Material';
$string['modulenameplural'] = 'Materiais';
$string['neverseen'] = 'Nunca visto';
$string['newdirectories'] = 'Mostrar links do diretrio';
$string['newfullscreen'] = 'Preencher toda a tela';
$string['newheight'] = 'Altura predefinida da janela (em pixels)';
$string['newlocation'] = 'Mostrar a brra de endereo';
$string['newmenubar'] = 'Mostrar a barra de menu';
$string['newresizable'] = 'Permitir redimensionamento da janela';
$string['newscrollbars'] = 'Permitir o escorrimento da janela';
$string['newstatus'] = 'Mostrar a barra de status';
$string['newtoolbar'] = 'Mostrar a barra de instrumentos';
$string['newwidth'] = 'Largura predefinida da janela (em pixels)';
$string['newwindow'] = 'Nova janela';
$string['newwindowopen'] = 'Mostre este material em uma janela popup';
$string['note'] = 'Nota';
$string['notefile'] = 'Para transferir mais arquivos ao curso (in modo que aparecerem nesta lista) use o <a href=$a>Administrador de Arquivos</a>.';
$string['notypechosen'] = 'Voc tem que escolher um tipo. Use seu boto de retorno e tente novamente.';
$string['popupresource'] = 'Este material deve ser mostrado em uma janela popup';
$string['popupresourcelink'] = 'Em caso contrrio, clicar aqui: $a';
$string['resourcetype'] = 'Tipo de material';
$string['resourcetype1'] = 'Referncia';
$string['resourcetype2'] = 'Pgina  Web';
$string['resourcetype3'] = 'Material arquivado no site';
$string['resourcetype4'] = 'Texto simples';
$string['resourcetype5'] = 'Endereo Web (link)';
$string['resourcetype6'] = 'Texto HTML';
$string['resourcetype7'] = 'Programa';
$string['resourcetype8'] = 'Texto Wiki';

?>

==> moodle_1.4.4.dfsg.1.orig.tar.gz: moodle/lang/pt_br/resource.php <==
<?PHP // $Id$ 
      // resource.php - created with Moodle 1.4.1 (2004083101)


$string['addresource'] = 'Adicionar material';
$string['chooseafile'] = 'Escolher ou carregar arquivo';
$string['chooseparameter'] = 'Escolher parmentro';
$string['configdefaulturl'] = 'Este valor  usado para completar o form da URL automaticamente quando o material  baseado em URL';
$string['configfilterexternalpages'] = 'Se esta opo estiver ativa, todos os materiais externos como paginas web e arquivos html carregados no servidor sero processados pelos filtros do site, como os autolinks do glossrio. Isto pode reduzir a velocidade de visualizao das pginas do curso - use esta opo apenas nos casos em que for realmente necessrio.';
$string['configframesize'] = 'Quando uma pgina web ou um arquivo  visualizado em um frame, este valor  o tamanho, em pixels, do frame que contm a navegao (top frame).';
$string['configparametersettings'] = 'Isto define o valr padro dos parmetros do painel do formulrio quando so adicionados novos materiais. Depois da primeira vez, passa a ser uma preferncia individual do usurio.';
$string['configpopup'] = 'A opo de visualizar os materiais em janela popup deve ser preconfigurada?';
$string['configpopupdirectories'] = 'As janelas popup devem mostrar o diretrio de links?';
$string['configpopupheight'] = 'Qual  a altura predefinida das janelas popup?';
$string['configpopuplocation'] = 'As janelas popup devem mostrar a barra de endereo?';
$string['configpopupmenubar'] = 'As janelas popup devem mostrar a barra do menu?';
$string['configpopupresizable'] = 'As janelas popup podem ser redimensionadas?';
$string['configpopupscrollbars'] = 'As janelas popup devem ter a barra de rolagem?';
$string['configpopupstatus'] = 'As janelas popup devem mostrar a brra de estado?';
$string['configpopuptoolbar'] = 'As janelas popup devem  mostrar a barra de instrumentos?';
$string['configpopupwidth'] = 'Qual  a largura predefinida das janelas popup?';
$string['configsecretphrase'] = 'Esta frase secreta  usada para produzir cdigos com valres cifrados que podem ser enviados aos materiais como parmetros. O cdigo cifrado  produzido por um valr md5 do endereo IP ligado a current_users e concatenado  frase secreta: code = md5(IP.secretphrase). isto permite ao destinatrio de verificar a conexo como medida adicional de segurana.';
$string['configwebsearch'] = 'Quando se adiciona uma URL como uma pgina web ou link, este endereo  apresentado como referimento para ajudar o usurio a buscar a URL que est procurando.';
$string['configwindowsettings'] = 'Isto define o valr padro do painel de configurao da janela do formulrio quando so adicionados novos materiais. Depois da primeira vez, passa a ser uma preferncia individual do usurio.';
$string['directlink'] = 'Direcionar link a este arquivo';
$string['directoryinfo'] = 'Todos os documentos no diretrio selecionado sero visualizados';
$string['display'] = 'Janela';
$string['editingaresource'] = 'Editar material';
$string['encryptedcode'] = 'Cdigo cifrado';
$string['example'] = 'Exemplo';
$string['exampleurl'] = 'http://www.exemplo.com/diretorio/arquivo.html';
$string['fetchclienterror'] = 'Um erro relacionado ao seu navegador impediu o acesso a este endereo (provavelmente o endereo no existe ou foi escrito em modo impreciso)';
$string['fetcherror'] = 'No foi possvel o acesso a esta pgina.';
$string['fetchservererror'] = 'Um erro de acesso ao servidor remoto foi identificado (provavelmente um erro daquele programa) </p>';
$string['filename'] = 'Nome do arquivo';
$string['filtername'] = 'Link automtico aos materiais';
$string['frameifpossible'] = 'Colocar o material em un frame par que a navegao do site continue visvel';
$string['fulltext'] = 'Texto completo';
$string['htmlfragment'] = 'Fragmento de HTML';
$string['maindirectory'] = 'Diretrio principal';
$string['modulename'] = 'Material';
$string['modulenameplural'] = 'Materiais';
$string['neverseen'] = 'Nunca visto';
$string['newdirectories'] = 'Mostrar links do diretrio';
$string['newfullscreen'] = 'Preencher toda a tela';
$string['newheight'] = 'Altura predefinida da janela (em pixels)';
$string['newlocation'] = 'Mostrar a brra de endereo';
$string['newmenubar'] = 'Mostrar a barra de menu';
$string['newresizable'] = 'Permitir redimensionamento da janela';
$string['newscrollbars'] = 'Permitir o escorrimento da janela';
$string['newstatus'] = 'Mostrar a barra de status';
$string['newtoolbar'] = 'Mostrar a barra de instrumentos';
$string['newwidth'] = 'Largura predefinida da janela (em pixels)';
$string['newwindow'] = 'Nova janela';
$string['newwindowopen'] = 'Mostre este material em uma janela popup';
$string['note'] = 'Nota';
$string['notefile'] = 'Para transferir mais arquivos ao curso (in modo que aparecerem nesta lista) use o <a href=$a>Administrador de Arquivos</a>.';
$string['notypechosen'] = 'Voc tem que escolher um tipo. Use seu boto de retorno e tente novamente.';
$string['pagedisplay'] = 'Visualizar este material nesta janela';
$string['pagewindow'] = 'Mesma janela';
$string['parameter'] = 'Parmetro';
$string['parameters'] = 'Parmetros';
$string['popupresource'] = 'Este material deve ser mostrado em uma janela popup';
$string['popupresourcelink'] = 'Em caso contrrio, clicar aqui: $a';
$string['resourcetype'] = 'Tipo de material';
$string['resourcetype1'] = 'Referncia';
$string['resourcetype2'] = 'Pgina Web';
$string['resourcetype3'] = 'Arquivo transferido ao site';
$string['resourcetype4'] = 'Texto Simples';
$string['resourcetype5'] = 'Link Web';
$string['resourcetype6'] = 'Texto HTML';
$string['resourcetype7'] = 'Programa';
$string['resourcetype8'] = 'Texto WIKI';
$string['resourcetype9'] = 'Diretrio';
$string['resourcetypedirectory'] = 'Visualizar diretrio';
$string['resourcetypefile'] = 'Fazer link a um arquivo ou site';
$string['resourcetypehtml'] = 'Criar uma pgina web';
$string['resourcetypelabel'] = 'Inserir rtulo';
$string['resourcetypetext'] = 'Criar uma pgina de texto simples';
$string['searchweb'] = 'Buscar pgina web';
$string['variablename'] = 'Nome da varivel';

?>
